pub(crate) struct BoxFragmentRareData {
pub(crate) resolved_sticky_insets: Option<Box<PhysicalSides<AuOrAuto>>>,
pub specific_layout_info: Option<SpecificLayoutInfo>,
}Fields
resolved_sticky_insets: Option<Box<PhysicalSides<AuOrAuto>>>The resolved box insets if this box is position: sticky. These are calculated
during StackingContextTree construction because they rely on the size of the
scroll container.
specific_layout_info: Option<SpecificLayoutInfo>Information that is specific to a layout system (e.g., grid, table, etc.).
Implementations
Sourceimpl BoxFragmentRareData
impl BoxFragmentRareData
Sourcefn try_boxed_from(
specific_layout_info: Option<SpecificLayoutInfo>,
) -> AtomicRefCell<Option<Box<Self>>>
fn try_boxed_from( specific_layout_info: Option<SpecificLayoutInfo>, ) -> AtomicRefCell<Option<Box<Self>>>
Create a new rare data based on information given to the fragment. Ideally, We should avoid creating rare data as much as possible to reduce the memory cost.